/**
\file main.c
\brief Code to Read Analog Data from ADC and Print in Serial Terminal

\verbatim

Created: 22-11-2020 03:20:10 PM
Author : Arnab Kumar Das
Website: www.ArnabKumarDas.com
Microcontroller Supported: ATmega48A/PA/88A/PA/168A/PA/328/P or Arduino UNO/NANO/MINI

Copyright (c) 2014-2020 Arnab Kumar Das
You may freely modify and share this code, as long as you keep this
notice intact (including the links above).
Licensed under the Creative Commons BY-SA 3.0 license:

  http://creativecommons.org/licenses/by-sa/3.0/

Disclaimer: To the extent permitted by law, Arnab Kumar Das provides this work
without any warranty.  It might be defective, in which case you agree
to be responsible for all resulting costs and damages.

                +-\/-+
          PC6  1|    |28  PC5 (A5/ADC5)
RXD  (D0) PD0  2|    |27  PC4 (A4/ADC4)
TXD  (D1) PD1  3|    |26  PC3 (A3/ADC3)
     (D2) PD2  4|    |25  PC2 (A2/ADC2)
PWM  (D3) PD3  5|    |24  PC1 (A1/ADC1)
XCK  (D4) PD4  6|    |23  PC0 (A0/ADC0)
          VCC  7|    |22  GND
          GND  8|    |21  AREF
          PB6  9|    |20  AVCC
          PB7 10|    |19  PB5 (D13)
OC0B (D5) PD5 11|    |18  PB4 (D12)
OC0A (D6) PD6 12|    |17  PB3 (D11) PWM
     (D7) PD7 13|    |16  PB2 (D10) PWM
     (D8) PB0 14|    |15  PB1 (D9)  PWM
                +----+

\endverbatim

*/ 

#include <avr/io.h>
#include "avr_adc.h"
#include "avr_usart.h"
#include <util/delay.h>


int main(void)
{
	/* ADC Configuration and Init */
	ADC_ConfigData ADC_Data;
	ADC_Data.Prescaler = ADC_PRESCALER_128;
	ADC_Data.VoltageReference = ADC_VOLTAGE_REFERENCE_AVCC;
	ADC_Init(ADC_Data);
	
	/* USART Configuration and Init */
	USART_ConfigData USART_Data;
	USART_Data.BaudRate = 9600;
	USART_Data.DataBit = USART_DATA_BIT_EIGHT;
	USART_Data.ParityBit = USART_PARITY_BIT_NO;
	USART_Data.StopBit = USART_STOP_BIT_ONE;
	USART_Data.UsartMode = USART_MODE_ASYNCHRONOUS;
	USART_Init(USART_Data);
    
	/* Local Variables */
	uint16_t ADC_RawData = 0x0000;
	float ADC_Voltage = 0.0f;
	
    while (1) 
    {
		/* Read ADC Value at Pin PC0 (A0/ADC0) */
		ADC_RawData = ADC_ReadPin(ADC0);
		
		/* Convert the raw ADC value to Voltage */
		ADC_Voltage = (float)( ADC_RawData * 5 ) / 1023;
		
		/* Print the data in terminal */
		USART_TransmitString("\nVoltage at ADC0 Pin = ");
		USART_WaitTillTransmitFree();
		USART_TransmitFloat(ADC_Voltage,3);
		
		/* Wait for 500ms */
		_delay_ms(500);
		
    }
}

