/**
\file main.c
\brief Code to Read Light Sensor / LDR value and Switch on a LED when it is Dark

\verbatim

Created: 22-11-2020 04:45:10 PM
Author : Arnab Kumar Das
Website: www.ArnabKumarDas.com
Microcontroller Supported: ATmega48A/PA/88A/PA/168A/PA/328/P or Arduino UNO/NANO/MINI

Copyright (c) 2014-2020 Arnab Kumar Das
You may freely modify and share this code, as long as you keep this
notice intact (including the links above).
Licensed under the Creative Commons BY-SA 3.0 license:

  http://creativecommons.org/licenses/by-sa/3.0/

Disclaimer: To the extent permitted by law, Arnab Kumar Das provides this work
without any warranty.  It might be defective, in which case you agree
to be responsible for all resulting costs and damages.

                +-\/-+
          PC6  1|    |28  PC5 (A5/ADC5)
RXD  (D0) PD0  2|    |27  PC4 (A4/ADC4)
TXD  (D1) PD1  3|    |26  PC3 (A3/ADC3)
     (D2) PD2  4|    |25  PC2 (A2/ADC2)
PWM  (D3) PD3  5|    |24  PC1 (A1/ADC1)
XCK  (D4) PD4  6|    |23  PC0 (A0/ADC0)
          VCC  7|    |22  GND
          GND  8|    |21  AREF
          PB6  9|    |20  AVCC
          PB7 10|    |19  PB5 (D13)
OC0B (D5) PD5 11|    |18  PB4 (D12)
OC0A (D6) PD6 12|    |17  PB3 (D11) PWM
     (D7) PD7 13|    |16  PB2 (D10) PWM
     (D8) PB0 14|    |15  PB1 (D9)  PWM
                +----+

\endverbatim

*/ 

#include <avr/io.h>
#include "avr_gpio.h"
#include "avr_adc.h"


int main(void)
{
	/* ADC Configuration and Init */
	ADC_ConfigData ADC_Data;
	ADC_Data.Prescaler = ADC_PRESCALER_128;
	ADC_Data.VoltageReference = ADC_VOLTAGE_REFERENCE_AVCC;
	ADC_Init(ADC_Data);
	
	/* GPIO Pin PB5 (D13) Configuration and Init */
	GPIO_InitPin(13,GPIO_MODE_OUTPUT);
	
	/* Local Variables */
	uint16_t ADC_RawData = 0x0000;	

	while (1)
	{
		/* Read ADC Value at Pin PC0 (A0/ADC0) */
		ADC_RawData = ADC_ReadPin(ADC0);
		
		if (ADC_RawData < 800)
		{
			GPIO_WritePinHigh(13);
		}
		else
		{
			GPIO_WritePinLow(13);
		}
		
	}
}

